@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,6 +32,8 @@
 #include "gcp-stock-pixbufs.h"
 #include "text.h"
 #include "plugin.h"
+#include "mechanism-arrow.h"
+#include "mechanism-step.h"
 #include "mesomer.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
@@ -52,6 +54,7 @@
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
 #include <gcu/loader.h>
+#include <gcu/loader-error.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
 #include <openbabel/reaction.h>
@@ -242,6 +245,21 @@ static Object* CreateFragment ()
 	return new Fragment ();
 }
 
+static Object* CreateMechanismArrow ()
+{
+	return new MechanismArrow ();
+}
+
+static Object* CreateMechanismStep ()
+{
+	return new MechanismStep (MechanismStepType);
+}
+
+static Object* CreateElectron ()
+{
+	return new Electron (NULL, false);
+}
+
 bool	Application::m_bInit = false;
 bool	Application::m_Have_Ghemical = false;
 bool	Application::m_Have_InChI = false;
@@ -302,7 +320,8 @@ Application::Application ():
 		Object::AddType ("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
 		Object::AddType ("text", CreateText, TextType);
 		Object::AddType ("fragment", CreateFragment, FragmentType);
-		ElectronType = Object::AddType ("electron", NULL);
+		ElectronType = Object::AddType ("electron", CreateElectron);
+		Object::AddAlias (ElectronType, "electron-pair");
 		// Add rules
 		Object::AddRule ("reaction", RuleMustContain, "reaction-step");
 		Object::AddRule ("reaction-step", RuleMustContain, "reactant");
@@ -320,6 +339,10 @@ Application::Application ():
 		Object::AddRule ("mesomery", RuleMustContain, "mesomer");
 		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
 		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
+		MechanismArrowType = Object::AddType ("mechanism-arrow", CreateMechanismArrow);
+		MechanismStepType = Object::AddType ("mechanism-step", CreateMechanismStep);
+		Object::AddRule ("reaction-step", RuleMayContain, "mechanism-step");
+		Object::AddRule ("mesomery", RuleMayContain, "mechanism-step");
 
 		// Create global signal ids
 		OnChangedSignal = Object::CreateNewSignalId ();
@@ -328,9 +351,19 @@ Application::Application ():
 
 		/* get the theme style for labels so that tools buttons colors might
 		be adapted to the current theme */
-		GtkWidget *w=gtk_label_new("");
-		m_Style = gtk_rc_get_style(w);
-		gtk_widget_destroy (w);
+		GtkWidget *w = gtk_label_new ("");
+		m_Style = GTK_STYLE (g_object_ref (gtk_rc_get_style (w)));
+		g_object_ref_sink (w);
+		g_object_unref (w);
+
+		// load settings before plugins
+		m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
+		GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
+		GCU_GCONF_GET ("invert-wedge-hashes", bool, InvertWedgeHashes, false)
+		bool CopyAsText;
+		GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
+		ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
+		m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, this);
 
 		// load plugins
 		Plugin::LoadPlugins ();
@@ -381,13 +414,6 @@ Application::Application ():
 		}
 	}
 	
-	m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
-	GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
-	GCU_GCONF_GET ("tearable-mendeleiev", bool, TearableMendeleiev, false)
-	bool CopyAsText;
-	GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
-	ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
-	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, this);
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
@@ -426,9 +452,13 @@ Application::~Application ()
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
 	TheThemeManager.Shutdown ();
+	g_object_unref (m_Style);
 	// unref cursors
 	for (int i = 0; i < CursorMax; i++)
 		gdk_cursor_unref (m_Cursors[i]);
+	if (m_entries)
+		g_free (RadioActions);
+	g_object_unref (IconFactory);
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -617,7 +647,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			}
 		}
 		g_object_unref (file);
-	} else  { //loading
+	} else  try { //loading
 		file = g_file_new_for_uri (filename);
 		err = g_file_query_exists (file, NULL);
 		g_object_unref (file);
@@ -663,6 +693,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			case ContentTypeSpectrum:
 				break;
 			default: {
+				pDoc->Loaded ();
 				double l = pDoc->GetMedianBondLength ();
 				if (l > 0.) {
 					double r = pDoc->GetBondLength () / l;
@@ -693,6 +724,22 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				OpenWithBabel (filename2, mime_type, pDoc);
 		}
 	}
+	catch (LoaderError &e) {
+		if (!pDoc)
+			pDoc = m_pActiveDoc;
+		pDoc->Clear ();
+		char *unescaped = g_uri_unescape_string (filename, NULL);
+		string mess = _("Error in ");
+		mess += unescaped;
+		// Note to translator: add a space if needed before the semicolon
+		mess += _(":\n");
+		mess += e.what ();
+		GtkWidget *message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess.c_str (), NULL, NULL);
+		g_free (unescaped);
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
+		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
+		gtk_widget_show (message);
+	}
 	return false;
 }
 
@@ -896,6 +943,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			g_error_free (error);
 			throw 1;
 		}
+		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
 		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
@@ -1120,8 +1168,8 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 				// set the pixbuf color to the corresponding style for the style
 				unsigned char red, blue, green;
 				red = m_Style->fg[c].red >> 8;
-				green = m_Style->fg[c].red >> 8;
-				blue = m_Style->fg[c].red >> 8;
+				green = m_Style->fg[c].green >> 8;
+				blue = m_Style->fg[c].blue >> 8;
 				unsigned char *line, *cur;
 				line = gdk_pixbuf_get_pixels (icon);
 				int i, j, rows, cols, rowstride;
@@ -1206,16 +1254,24 @@ void Application::ActivateWindowsActionWidget (const char *path, bool activate)
 	}
 }
 
+void Application::UpdateAllTargets ()
+{
+	set <Target *>::iterator target, tend = m_Targets.end ();
+	for (target = m_Targets.begin (); target != tend; target++) {
+		Document *doc = (*target)->GetDocument ();
+		doc->GetView ()->Update (doc);
+	}
+	// now propagate to tools
+	std::map <std::string, Tool*>::iterator i, iend = m_Tools.end ();
+	for (i = m_Tools.begin (); i != iend; i++)
+		(*i).second->OnConfigChanged ();
+}
+
 void Application::OnConfigChanged (GOConfNode *node, gchar const *name)
 {
 	GCU_UPDATE_KEY ("compression", int, CompressionLevel, {})
-	GCU_UPDATE_KEY ("tearable-mendeleiev", bool, TearableMendeleiev,
-					{
-						Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
-						if (ToolsBox)
-							ToolsBox->Update ();
-					})
 	bool CopyAsText;
+	GCU_UPDATE_KEY ("invert-wedge-hashes", bool, InvertWedgeHashes, UpdateAllTargets ();)
 	GCU_UPDATE_KEY ("copy-as-text", bool, CopyAsText, ClipboardFormats = CopyAsText?GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;)
 }
 
@@ -1268,26 +1324,6 @@ void Application::BuildMenu (GtkUIManager *manager)
 		(*i) (manager);
 }
 
-struct option_data {
-	GOptionEntry const *entries;
-	char const *translation_domain;
-};
-
-void Application::RegisterOptions (GOptionEntry const *entries, char const *translation_domain)
-{
-	struct option_data d;
-	d.entries = entries;
-	d.translation_domain = translation_domain;
-	m_Options.push_back (d);
-}
-
-void Application::AddOptions (GOptionContext *context)
-{
-	list<option_data>::iterator i, end = m_Options.end ();
-	for (i = m_Options.begin (); i != end; i++)
-		g_option_context_add_main_entries (context, (*i).entries, (*i).translation_domain);
-}
-
 gcu::Document *Application::CreateNewDocument ()
 {
 	return new Document (this, true, NULL);
