@@ -25,7 +25,7 @@
 #ifndef GCHEMPAINT_REACTION_STEP_H
 #define GCHEMPAINT_REACTION_STEP_H
 
-#include <mechanism-step.h>
+#include <gcp/mechanism-step.h>
 #include <gccv/structs.h>
 #include <set>
 
@@ -65,7 +65,7 @@ The destructor.
 Buils a new reaction step from the children and adds as many eaction operators
 as necessary. All children will be horizontally aligned.
 */
-	ReactionStep (Reaction *reaction, std::map<double, gcu::Object*>& Children, std::map<gcu::Object*, gccv::Rect> Objects);
+	ReactionStep (Reaction *reaction, std::map<double, gcu::Object*>& Children, std::map<gcu::Object*, gccv::Rect> Objects) throw (std::invalid_argument);
 /*!
 @param xml the xmlDoc used to save the document.
 
@@ -111,8 +111,14 @@ not anymore relevant.
 */
 	void RemoveArrow (ReactionArrow *arrow);
 
+/*!
+@return the localized object generic name.
+*/
 	std::string Name ();
 
+private:
+	void CleanChildren ();
+
 private:
 	bool m_bLoading;
 	std::set<ReactionArrow *> m_Arrows;
