@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/application.h
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,15 +26,11 @@
 #define GCU_APPLICATION_H
 
 #include "dialog-owner.h"
+#include "structs.h"
+#include <list>
 #include <map>
 #include <set>
 #include <string>
-#ifdef HAVE_GO_CONF_SYNC
-#include <goffice/app/go-conf.h>
-#endif
-#include <gtk/gtkmain.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkrecentmanager.h>
 #include <gcu/macros.h>
 
 /*!\file*/
@@ -42,16 +38,40 @@ namespace gcu {
 
 class Document;
 class Dialog;
+struct option_data;
+
+/*!
+Window states
+*/
+typedef enum {
+/*!
+Normal window.
+*/
+	NormalWindowState,
+/*!
+Maximized window.
+*/
+	MaximizedWindowState,
+/*!
+Minimized window.
+*/
+	MinimizedWindowState,
+/*!
+Full screen window.
+*/
+	FullScreenWindowState
+} WindowState;
 
 #define GCU_CONF_DIR "gchemutils"
 
 /*!\class Application gcu/application.h
 This class is a base class for applications. It provides some basic services.
 */
-class Application: public DialogOwner
+class Application: virtual public DialogOwner
 {
 friend class Document;
 friend class Dialog;
+friend class ApplicationPrivate;
 public:
 /*!
 @param name the name of the application.
@@ -106,7 +126,7 @@ if they use the FileChooser.
 	
 @return true if no error occured.
 */
-	virtual bool FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *pDoc = NULL)
+	virtual bool FileProcess (G_GNUC_UNUSED const gchar* filename, G_GNUC_UNUSED const gchar* mime_type, G_GNUC_UNUSED bool bSave, G_GNUC_UNUSED GtkWindow *window, G_GNUC_UNUSED Document *pDoc = NULL)
 		{return false;}
 
 /*!
@@ -196,18 +216,19 @@ This method loads a document using the appropriate gcu::Loader class
 instance.
 @return true if no error occurred.
 */
-	bool Load (std::string const &uri, const gchar *mime_type, Document* Doc);
+	ContentType Load (std::string const &uri, const gchar *mime_type, Document* Doc);
 
 /*!
 @param uri the uri to which the document should be saved.
 @param mime_type the mime type of the document.
 @param Doc the document instance which contains the data to be saved.
+@param type the type of the data to be saved (see gcu::ContentType).
 
 This method saves the document using the appropriate gcu::Loader class
 instance.
 @return true if no error occurred.
 */
-	bool Save (std::string const &uri, const gchar *mime_type, Document* Doc);
+	bool Save (std::string const &uri, const gchar *mime_type, Document const *Doc, ContentType type);
 
 /*!
 Virtual method used to create documents. Default behavior does nothing and returns NULL.
@@ -215,17 +236,44 @@ Virtual method used to create documents. Default behavior does nothing and retur
 */
 	virtual Document *CreateNewDocument () {return NULL;}
 
-#ifdef HAVE_GO_CONF_SYNC
-
 /*!
 Method used to retrieve the base configuration node.
 @return the base configuration node.
 */
 	static GOConfNode *GetConfDir ();
-#endif
 
+/*!
+Retrieves the icon name that should be set to every window owned by the application.
+@return the icon name for the appication.
+*/
 	std::string const &GetIconName () {return IconName;}
 
+/*!
+@param entries: the entries to register.
+@param translation_domain: the entries to register.
+
+Adds new command line options. Typically called from a plugin. The new
+options are added to the main group.
+*/
+	void RegisterOptions (GOptionEntry const *entries, char const *translation_domain = GETTEXT_PACKAGE);
+
+/*!
+@param context: a GOptionContext
+
+Adds all registered options to the context. This should be called once
+just after creating the application and before parsing options.
+*/
+	void AddOptions (GOptionContext *context);
+/*!
+@return the default WindowState for the application. New window should use this setting.
+*/
+	static WindowState GetDefaultWindowState () {return DefaultWindowState;}
+/*!
+@return a dummy Application instance which might be used when there is no other
+Application available.
+*/
+	static Application *GetDefaultApplication ();
+
 protected:
 
 /*!
@@ -246,9 +294,9 @@ private:
 	std::string HelpFilename;
 	std::string CurDir;
 	std::string IconName;
-#ifdef HAVE_GO_CONF_SYNC
 	static GOConfNode *m_ConfDir;
-#endif
+	std::list<option_data> m_Options;
+	static WindowState DefaultWindowState;
 
 protected:
 /*!
@@ -309,7 +357,7 @@ an exported image size, but not both.
 @return the current image height used on export as a reference.
 */
 GCU_PROP (unsigned, ImageHeight)
-/*!\fn SetTransparentBackground(bool transpasrent)
+/*!\fn SetTransparentBackground(bool transparent)
 @param transparent whether an export image should have a transparent background.
 
 Sets the transparency of the exported image when possible.
