@@ -4,7 +4,7 @@
  * Gnome Chemisty Utils
  * macros.h 
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,11 +25,7 @@
 #ifndef GCU_MACROS_H
 #define GCU_MACROS_H
 
-#ifdef HAVE_GO_CONF_SYNC
-#	include <goffice/app/go-conf.h>
-#else
-#	include <gconf/gconf-client.h>
-#endif
+#include <goffice/goffice.h>
 
 /*!\file */ 
 /*!\def GCU_PROP()
@@ -165,51 +161,25 @@ This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs or if the value is 0,
 \a defaultval is used instead.\n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define go_conf_get_float go_conf_get_double
 #define GCU_GCONF_GET(key,type,target,defaultval) \
 	target = go_conf_get_##type (m_ConfNode, key); \
 	if (target == (type) 0)	\
 		target = defaultval;
-#else
-#define GCU_GCONF_GET(key,type,target,defaultval) \
-	target = gconf_client_get_##type (m_ConfClient, ROOTDIR key, &error); \
-	if (error) {	\
-		target = defaultval;	\
-		g_message ("GConf failed: %s", error->message);	\
-		g_error_free (error);	\
-		error = NULL;	\
-	}	\
-	if (target == (type) 0)	\
-		target = defaultval;
-#endif
 /*!\def GCU_GCONF_GET_NO_CHECK()
 This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs, \a defaultval is used instead.\n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_NO_CHECK(key,type,target,defaultval) \
 	target = go_conf_get_##type (m_ConfNode, key);
-#else
-#define GCU_GCONF_GET_NO_CHECK(key,type,target,defaultval) \
-	target = gconf_client_get_##type (m_ConfClient, ROOTDIR key, &error); \
-	if (error) {	\
-		target = defaultval;	\
-		g_message ("GConf failed: %s", error->message);	\
-		g_error_free (error);	\
-		error = NULL;	\
-	}
-#endif
 
 /*!\def GCU_GCONF_GET_N_TRANSFORM()
 This macro gets the numerical value of type \a type associated to \a key. If an error
@@ -217,12 +187,10 @@ occurs or if the value is 0, \a defaultval is used instead.\n
 The resuting value (which might be the default value) is then passed
 to \a func and the result is copied to \a target. \n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_N_TRANSFORM(key,type,target,defaultval,func) \
 	{	\
 		type val = go_conf_get_##type (m_ConfNode, key); \
@@ -230,32 +198,16 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 			val = defaultval; \
 		target = func (val);	\
 	}
-#else
-#define GCU_GCONF_GET_N_TRANSFORM(key,type,target,defaultval,func) \
-	{	\
-		type val = gconf_client_get_##type (m_ConfClient, ROOTDIR key, &error); \
-		if (error) {	\
-			val = defaultval;	\
-			g_message ("GConf failed: %s", error->message);	\
-			g_error_free (error);	\
-			error = NULL;	\
-		}	\
-		if (val == (type) 0)	\
-			val = defaultval; \
-		target = func (val);	\
-	}
-#endif
 
 /*!\def GCU_GCONF_GET_STRING()
 This macro gets the string value associated to \a key, and
 copies it to \a target. If an error occurs, \a defaultval is used instead.\n
 If \a target is not NULL when entering the macro, it is deallocated using g_free
 and set to NULL before calling gconf_client_get_string.\n
-Calling class must have a GConfClient member called m_ConfClient, and the code
+Calling class must have a GOConfNode called m_ConfNode, and the code
 must provide a GError *error initially set to NULL.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_STRING(key,target,defaultval) \
 	if (target) {	\
 		g_free (target);	\
@@ -264,67 +216,31 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 	target = go_conf_get_string (m_ConfNode, key); \
 	if (target == NULL && defaultval)	\
 		target = g_strdup (defaultval);
-#else
-#define GCU_GCONF_GET_STRING(key,target,defaultval) \
-	if (target) {	\
-		g_free (target);	\
-		target = NULL;	\
-	}	\
-	target = gconf_client_get_string (m_ConfClient, ROOTDIR key, &error); \
-	if (error) {	\
-		if (defaultval)	\
-			target = g_strdup (defaultval);	\
-		g_message ("GConf failed: %s", error->message);	\
-		g_error_free (error);	\
-		error = NULL;	\
-	} else if (target == NULL && defaultval)	\
-			target = g_strdup (defaultval);
-#endif
 
 /*!\def GCU_UPDATE_KEY()
 This macro updates a value of type \a type associated to \a key, and
 copies it to \a target. \a action is called after setting the target?
-It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
-on the GOffice library version.
+It also needs a GOConfNode* called node.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define GCU_UPDATE_KEY(key,type,target,action) \
 	if (!strcmp (name, ROOTDIR key)) { \
 		target = go_conf_get_##type (node, ((node)? key: ROOTDIR key)); \
 		action \
 		return; \
 	}
-#else
-#define GCU_UPDATE_KEY(key,type,target,action) \
-	if (!strcmp (gconf_entry_get_key (entry), ROOTDIR key)) { \
-		target = gconf_value_get_##type (gconf_entry_get_value (entry)); \
-		action \
-		return; \
-	}
-#endif
 
 /*!\def GCU_UPDATE_STRING_KEY()
 This macro updates a string value associated to \a key, and
 copies it to \a target. \a action is called after setting the target?
-It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
-on the GOffice library version.
+It also needs a GOConfNode* called node.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
-#ifdef HAVE_GO_CONF_SYNC
 #define GCU_UPDATE_STRING_KEY(key,target,action) \
 	if (!strcmp (name, ROOTDIR key)) { \
 		target = go_conf_get_string (node, ((node)? key: ROOTDIR key)); \
 		action \
 		return; \
 	}
-#else
-#define GCU_UPDATE_STRING_KEY(key,target,action) \
-	if (!strcmp (gconf_entry_get_key (entry), ROOTDIR key)) { \
-		target = g_strdup (gconf_value_get_string (gconf_entry_get_value (entry))); \
-		action \
-		return; \
-	}
-#endif
 
 #endif	//	GCU_MACROS_H
