@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * object.h 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -42,6 +42,8 @@
 namespace gcu
 {
 
+class Dialog;
+
 /*!\enum GcuTypeId
 This enumeration is used to determine the type of an Object instance.
 Possible values are:
@@ -518,6 +520,27 @@ Deletes all children. Derived classes might override this method if needed.
 */
 	virtual void Clear ();
 
+/*!
+@return the object generic name.
+*/
+	virtual std::string Name ();
+
+/*!
+@return the object identity composed of the object name as returned by
+gcu::Object::Name() concatenated with its unique Id as returned by gcu::Object::GetId().
+*/
+	std::string Identity ();
+
+/*!
+@return the name of the properties dialog for this object if one exists, or NULL.
+*/
+	virtual char const *HasPropertiesDialog () const;
+
+/*!
+Exposes the gcu::Dialog related to the object properties if it exists.
+*/
+	void ShowPropertiesDialog ();
+
 /*!
 @param TypeName the name of the new type.
 @param CreateFunc a pointer to a function returning a pointer to a new object of the new type.
@@ -529,6 +552,14 @@ This method is used to register a new type derived from Object.
 */
 	static TypeId AddType (std::string TypeName, Object* (*CreateFunc) (), TypeId id = OtherType);
 
+/*!
+@param id the Id of an existing type.
+@param TypeName a new name for the type.
+
+This method is used to add an alternative name to an existing type.
+*/
+	static void AddAlias (TypeId id, std::string TypeName);
+
 /*!
 @param TypeName the name of the new type.
 @param parent the parent of the newly created object or NULL. if NULL, the parameter can be omitted.
@@ -625,6 +656,12 @@ the class seems possible.
 */
 	static SignalId CreateNewSignalId ();
 
+protected:
+/*!
+@return the gcu::Dialog related to the object properties or NULL if none exists.
+*/
+	virtual Dialog *BuildPropertiesDialog ();
+
 private:
 	Object* RealGetDescendant (const gchar* Id) const;
 
