@@ -16,15 +16,20 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <config.h>
 #include "npapi.h"
-#include "npupp.h"
+#ifdef HAVE_NPFUNCTIONS_H
+#   include "npfunctions.h"
+#else
+#   include "npupp.h"
+#endif
 #include <unistd.h>
 #include <string.h>
+#include <glib.h>
 
 static NPNetscapeFuncs mozilla_funcs;
 static int pid = 0;
@@ -44,11 +49,18 @@ typedef struct {
 	char **args;
 	pthread_t thread;*/
 	NPP instance;
+
+	NPStream *m_Stream;
+	bool m_ExpectingStream;
 } ChemPlugin;
 
 static NPError ChemNew (NPMIMEType mime_type, NPP instance,
-				 uint16 mode, uint16 argc, char *argn[], char *argv[],
-				 NPSavedData *saved)
+#ifdef HAVE_NPFUNCTIONS_H
+				 G_GNUC_UNUSED uint16_t mode, uint16_t argc, char *argn[], char *argv[],
+#else
+				 G_GNUC_UNUSED uint16 mode, uint16 argc, char *argn[], char *argv[],
+#endif
+				 G_GNUC_UNUSED NPSavedData *saved)
 {
 	ChemPlugin *plugin;
 	char buf [32];
@@ -83,7 +95,7 @@ static NPError ChemNew (NPMIMEType mime_type, NPP instance,
 			close (p[0]);
 			to_pipe = p[1];
 		} else {
-			close(p[1]);
+			close (p[1]);
 			if (p[0] != STDIN_FILENO){
 				if (dup2 (p[0], STDIN_FILENO) != STDIN_FILENO) {
 					perror("dup2 (stdin)");
@@ -101,18 +113,22 @@ static NPError ChemNew (NPMIMEType mime_type, NPP instance,
 	write (to_pipe, mime_type, strlen ((char*) mime_type));
 	write (to_pipe, "\n", 1);
 	i = 0;
-	while (strcmp (argn[i++], "PARAM"));
+	while (i < argc && strcmp (argn[i++], "PARAM"));
 	for (; i < argc; i++) {
+		if (argn[i] == NULL || argv[i] == NULL)
+			break;
 		write (to_pipe, argn[i], strlen (argn[i]));
 		write (to_pipe, "\n", 1);
 		write (to_pipe, argv[i], strlen (argv[i]));
 		write (to_pipe, "\n", 1);
 	}
 	write (to_pipe, "end\n", 4);
+	plugin->m_Stream = NULL;
+	plugin->m_ExpectingStream = true;
 	return NPERR_NO_ERROR;
 }
 
-static NPError ChemDestroy (NPP instance, NPSavedData **save)
+static NPError ChemDestroy (NPP instance, G_GNUC_UNUSED NPSavedData **save)
 {
 	ChemPlugin *plugin;
 	char buf[32];
@@ -144,28 +160,53 @@ static NPError ChemSetWindow (NPP instance, NPWindow *window)
 	return NPERR_NO_ERROR;
 }
 
-static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
-		      NPBool seekable, uint16 *stype)
+static NPError ChemNewStream (NPP instance, G_GNUC_UNUSED NPMIMEType type, G_GNUC_UNUSED NPStream *stream,
+#ifdef HAVE_NPFUNCTIONS_H
+		      G_GNUC_UNUSED NPBool seekable, uint16_t *stype)
+#else
+		      G_GNUC_UNUSED NPBool seekable, uint16 *stype)
+#endif
 {
+	if (!stream || !stream->url)
+		return NPERR_GENERIC_ERROR;
+
 	ChemPlugin *plugin;
 
 	if (instance == NULL)
 		return NPERR_INVALID_INSTANCE_ERROR;
-	
+
 	plugin = (ChemPlugin *) instance->pdata;
 	if (plugin == NULL)
-		return NPERR_NO_ERROR;	
-	
+		return NPERR_INVALID_INSTANCE_ERROR;	
+
+	if (plugin->m_Stream || !plugin->m_ExpectingStream)
+		return mozilla_funcs.destroystream (instance, stream, NPRES_DONE);
+
+	plugin->m_ExpectingStream = false;
+	plugin->m_Stream = stream;
+
 	*stype = NP_ASFILEONLY;
 
 	return NPERR_NO_ERROR;
 }
 
-static void ChemPrint (NPP instance, NPPrint *platformPrint)
+static NPError ChemDestroyStream (G_GNUC_UNUSED NPP instance, G_GNUC_UNUSED NPStream* stream, G_GNUC_UNUSED NPReason reason)
 {
+	if (instance == NULL)
+		return NPERR_INVALID_INSTANCE_ERROR;
+	ChemPlugin *plugin = (ChemPlugin *) instance->pdata;
+	if (!plugin->m_Stream || plugin->m_Stream != stream)
+		return NPERR_GENERIC_ERROR;
+	plugin->m_Stream = NULL;
+	return NPERR_NO_ERROR;
 }
 
-static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
+static void ChemPrint (G_GNUC_UNUSED NPP instance, G_GNUC_UNUSED NPPrint *platformPrint)
+{
+// TODO: implement !!!
+}
+
+static void ChemStreamAsFile (NPP instance, G_GNUC_UNUSED NPStream *stream, const char *fname)
 {
 	char buf[32];
 	write (to_pipe, "file\n", 5);
@@ -175,7 +216,7 @@ static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
 	write (to_pipe, "\n", 1);
 }
 
-NPError NP_GetValue (void *future, NPPVariable variable, void *value)
+NPError NP_GetValue (G_GNUC_UNUSED void *future, NPPVariable variable, void *value)
 {
 	switch (variable) {
 	case NPPVpluginNameString:
@@ -197,7 +238,12 @@ char *NP_GetMIMEDescription (void)
 	return ("chemical/x-xyz:xyz:XYZ Coordinate Format;"
 			"chemical/x-mdl-molfile:mol:MDL Molfile;"
 			"chemical/x-pdb:pdb,ent:Protein DataBank;"
-			"application/x-gcrystal:gcrystal:Crystalline structure model");
+			"chemical/x-jcamp-dx:dx,jdx:JCAMP Spectroscopic Data Exchange Format;"
+			"application/x-gcrystal:gcrystal:Crystalline structure model;"
+			"chemical/x-cif:cif:Crystallographic Information File;"
+			"application/x-gchempaint:gchempaint:2D chemical structures"
+			"chemical/x-cdx:cdx:ChemDraw binary CDX format;"
+			"chemical/x-cdxml:cdxml:ChemDraw CDXML format;");
 }
 
 /* This is called to initialise the plugin
@@ -214,18 +260,30 @@ NPError NP_Initialize(NPNetscapeFuncs *mozFuncs, NPPluginFuncs *pluginFuncs) {
 		return NPERR_INVALID_FUNCTABLE_ERROR;
 
 	memcpy (&mozilla_funcs, mozFuncs, sizeof (NPNetscapeFuncs));
-	
 	pluginFuncs->version    = (NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR;
 	pluginFuncs->size       = sizeof (NPPluginFuncs);
+#ifdef HAVE_NPFUNCTIONS_H
+	pluginFuncs->newp       = (NPP_NewProcPtr)ChemNew;
+	pluginFuncs->destroy    = (NPP_DestroyProcPtr) ChemDestroy;
+	pluginFuncs->setwindow  = (NPP_SetWindowProcPtr) ChemSetWindow;
+	pluginFuncs->newstream  = (NPP_NewStreamProcPtr) ChemNewStream;
+	pluginFuncs->destroystream  = (NPP_DestroyStreamProcPtr) ChemDestroyStream;
+	pluginFuncs->asfile     = (NPP_StreamAsFileProcPtr) ChemStreamAsFile;
+#else
 	pluginFuncs->newp       = NewNPP_NewProc (ChemNew);
 	pluginFuncs->destroy    = NewNPP_DestroyProc (ChemDestroy);
 	pluginFuncs->setwindow  = NewNPP_SetWindowProc (ChemSetWindow);
 	pluginFuncs->newstream  = NewNPP_NewStreamProc (ChemNewStream);
-	pluginFuncs->destroystream = NULL;
+	pluginFuncs->destroystream  = NewNPP_DestroyStreamProcPtr (ChemDestroyStream);
 	pluginFuncs->asfile     = NewNPP_StreamAsFileProc (ChemStreamAsFile);
+#endif
 	pluginFuncs->writeready = NULL;
 	pluginFuncs->write      = NULL;
+#ifdef HAVE_NPFUNCTIONS_H
+	pluginFuncs->print      = (NPP_PrintProcPtr) ChemPrint;
+#else
 	pluginFuncs->print      = NewNPP_PrintProc (ChemPrint);
+#endif
 	pluginFuncs->urlnotify  = NULL;
 	pluginFuncs->event      = NULL;
 #ifdef OJI
