@@ -23,6 +23,7 @@
  */
 
 #include "config.h"
+#include <gcu/application.h>
 #include <gcu/atom.h>
 #include <gcu/bond.h>
 #include <gcu/document.h>
@@ -51,14 +52,36 @@ using namespace gcu;
 
 static map<string, unsigned> KnownProps;
 
+typedef struct {
+	unsigned index;
+	string encoding;
+	string name;
+} CDXMLFont;
+
 class CDXMLLoader: public gcu::Loader
 {
 public:
 	CDXMLLoader ();
 	virtual ~CDXMLLoader ();
 
-	bool Read (Document *doc, GsfInput *in, char const *mime_type, IOContext *io);
-	bool Write (Document *doc, GsfOutput *out, char const *mime_type, IOContext *io);
+	ContentType Read (Document *doc, GsfInput *in, char const *mime_type, GOIOContext *io);
+	bool Write (Object *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
+
+private:
+	bool WriteObject (xmlDocPtr xml, xmlNodePtr node, Object *object, GOIOContext *io);
+	static void AddIntProperty (xmlNodePtr node, char const *id, int value);
+	static void AddStringProperty (xmlNodePtr node, char const *id, string &value);
+	static bool WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
+	static bool WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
+	static bool WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
+
+private:
+	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object *, GOIOContext *)> m_WriteCallbacks;
+	map <unsigned, GOColor> m_Colors;
+	map <unsigned, CDXMLFont> m_Fonts;
+	map <string, unsigned> m_SavedIds;
+	int m_MaxId;
+	unsigned m_Z;
 };
 
 CDXMLLoader::CDXMLLoader ()
@@ -81,6 +104,10 @@ CDXMLLoader::CDXMLLoader ()
 	KnownProps["LabelJustification"] =GCU_PROP_TEXT_JUSTIFICATION;
 	KnownProps["Justification"] =GCU_PROP_TEXT_JUSTIFICATION;
 	KnownProps["LabelAlignment"] = GCU_PROP_TEXT_ALIGNMENT;
+	// Add write callbacks
+	m_WriteCallbacks["atom"] = WriteAtom;
+	m_WriteCallbacks["bond"] = WriteBond;
+	m_WriteCallbacks["molecule"] = WriteMolecule;
 }
 
 CDXMLLoader::~CDXMLLoader ()
@@ -94,15 +121,9 @@ typedef struct {
 	string value;
 } CDXMLProps;
 
-typedef struct {
-	unsigned index;
-	string encoding;
-	string name;
-} CDXMLFont;
-
 typedef struct {
 	Document *doc;
-	IOContext *context;
+	GOIOContext *context;
 	stack<Object*> cur;
 	list<CDXMLProps> failed;
 	map<unsigned, CDXMLFont> fonts;
@@ -137,7 +158,7 @@ cdxml_doc (GsfXMLIn *xin, xmlChar const **attrs)
 }
 
 static void
-cdxml_fragment_start (GsfXMLIn *xin, xmlChar const **attrs)
+cdxml_fragment_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 {
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
 	Object *obj = Object::CreateObject ("molecule", state->cur.top ());
@@ -376,7 +397,7 @@ cdxml_string_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 }
 
 static void
-fragment_done (GsfXMLIn *xin, CDXMLReadState *state)
+fragment_done (G_GNUC_UNUSED GsfXMLIn *xin, CDXMLReadState *state)
 {
 	Object *atom = state->cur.top (), *child;
 	state->cur.pop ();
@@ -591,7 +612,7 @@ cdxml_color (GsfXMLIn *xin, xmlChar const **attrs)
 }
 
 static void
-cdxml_group_start (GsfXMLIn *xin, xmlChar const **attrs)
+cdxml_group_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 {
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
 	Object *obj = Object::CreateObject ("group", state->cur.top ());
@@ -712,13 +733,13 @@ GSF_XML_IN_NODE (CDXML, CDXML, -1, "CDXML", GSF_XML_CONTENT, &cdxml_doc, NULL),
 GSF_XML_IN_NODE_END
 };
 
-bool CDXMLLoader::Read  (Document *doc, GsfInput *in, char const *mime_type, IOContext *io)
+ContentType CDXMLLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char const *mime_type, GOIOContext *io)
 {
 	CDXMLReadState state;
 
 	state.doc = doc;
 	state.context = io;
-	bool  success = false;
+	ContentType success = ContentTypeUnknown;
 	state.colors.push_back ("red=\"1\" green=\"1\" blue=\"1\""); // white
 	state.colors.push_back ("red=\"0\" green=\"0\" blue=\"0\""); // black
 	state.font = 0;
@@ -726,10 +747,11 @@ bool CDXMLLoader::Read  (Document *doc, GsfInput *in, char const *mime_type, IOC
 
 	if (NULL != in) {
 		GsfXMLInDoc *xml = gsf_xml_in_doc_new (cdxml_dtd, NULL);
-		success = gsf_xml_in_doc_parse (xml, in, &state);
+		if (gsf_xml_in_doc_parse (xml, in, &state))
+			success = ContentType2D;
 
-		if (!success)
-			gnm_io_warning (state.context,
+		if (success == ContentTypeUnknown)
+			go_io_warning (state.context,
 				_("'%s' is corrupt!"),
 				gsf_input_name (in));
 		else if (!state.failed.empty ()) {
@@ -743,8 +765,8 @@ bool CDXMLLoader::Read  (Document *doc, GsfInput *in, char const *mime_type, IOC
 						parent = p.obj->GetParent ();
 				}
 				if (!p.obj->SetProperty (p.property, p.value.c_str ())) {
-					success = false;
-					gnm_io_warning (state.context,
+					success = ContentTypeUnknown;
+					go_io_warning (state.context,
 						_("'%s' is corrupt!"),
 						gsf_input_name (in));
 				}
@@ -761,19 +783,222 @@ bool CDXMLLoader::Read  (Document *doc, GsfInput *in, char const *mime_type, IOC
 ////////////////////////////////////////////////////////////////////////////////
 // Writing code
 
-bool CDXMLLoader::Write  (Document *doc, GsfOutput *out, char const *mime_type, IOContext *io)
+static bool start = true;
+static int cb_xml_to_vfs (GsfOutput *output, const guint8* buf, int nb)
+{
+	if (start) {
+		char const *end = strchr (reinterpret_cast <char const *> (buf), '\n');
+		gsf_output_write (output, 40, reinterpret_cast <guint8 const *> ("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"));
+		gsf_output_write (output, 70, reinterpret_cast <guint8 const *> ("<!DOCTYPE CDXML SYSTEM \"http://www.cambridgesoft.com/xml/cdxml.dtd\" >\n"));
+		start = false;
+		return gsf_output_write (output, strlen (end) - 1, reinterpret_cast <guint8 const *> (end + 1))? nb: 0;
+	} else
+		return gsf_output_write (output, nb, buf)? nb: 0;
+}
+
+bool CDXMLLoader::WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, G_GNUC_UNUSED GOIOContext *s)
+{
+	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("n"), NULL);
+	xmlAddChild (parent, node);
+	loader->m_SavedIds[obj->GetId ()] = loader->m_MaxId;
+	AddIntProperty (node, "id", loader->m_MaxId++);
+	string prop = obj->GetProperty (GCU_PROP_POS2D);
+	AddStringProperty (node, "p", prop);
+	AddIntProperty (node, "Z", loader->m_Z++);	
+	prop = obj->GetProperty (GCU_PROP_ATOM_Z);
+	if (prop != "6")
+		AddStringProperty (node, "Element", prop);
+	return true;
+}
+
+bool CDXMLLoader::WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, G_GNUC_UNUSED GOIOContext *s)
+{
+	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("b"), NULL);
+	xmlAddChild (parent, node);
+	loader->m_SavedIds[obj->GetId ()] = loader->m_MaxId;
+	AddIntProperty (node, "id", loader->m_MaxId++);
+	AddIntProperty (node, "Z", loader->m_Z++);	
+	string prop = obj->GetProperty (GCU_PROP_BOND_BEGIN);
+	AddIntProperty (node, "B", loader->m_SavedIds[prop]);
+	prop = obj->GetProperty (GCU_PROP_BOND_END);
+	AddIntProperty (node, "E", loader->m_SavedIds[prop]);
+	prop = obj->GetProperty (GCU_PROP_BOND_ORDER);
+	if (prop == "3")
+		prop = "4";
+	else if (prop != "2")
+		prop.clear ();
+	if (prop.length ())
+		AddStringProperty (node, "Order", prop);
+	prop = obj->GetProperty (GCU_PROP_BOND_TYPE);
+	if (prop == "wedge")
+		prop = "WedgeBegin";
+	else if (prop == "hash")
+		prop = "WedgedHashBegin";
+	else if (prop == "squiggle")
+		prop = "Wavy";
+	else
+		prop.clear ();
+	if (prop.length ())
+		AddStringProperty (node, "Display", prop);
+	return true;
+}
+
+bool CDXMLLoader::WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s)
+{
+	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("fragment"), NULL);
+	xmlAddChild (parent, node);
+	loader->m_SavedIds[obj->GetId ()] = loader->m_MaxId;
+	AddIntProperty (node, "id", loader->m_MaxId++);
+	// save atoms
+	std::map <std::string, Object *>::iterator i;
+	Object *child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == AtomType && !loader->WriteObject (xml, node, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	// save fragments
+	child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == FragmentType && !loader->WriteObject (xml, node, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	// save bonds
+	child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == BondType && !loader->WriteObject (xml, node, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	return true;
+}
+
+bool CDXMLLoader::WriteObject (xmlDocPtr xml, xmlNodePtr node, Object *object, GOIOContext *io)
+{
+	string name = Object::GetTypeName (object->GetType ());
+	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object *, GOIOContext *)>::iterator i = m_WriteCallbacks.find (name);
+	if (i != m_WriteCallbacks.end ())
+		return (*i).second (this, xml, node, object, io);
+	// if we don't save the object iself, try to save its children
+	std::map <std::string, Object *>::iterator j;
+	Object *child = object->GetFirstChild (j);
+	while (child) {
+		if (!WriteObject (xml, node, child, io))
+			return false;
+		child = object->GetNextChild (j);
+	}
+	return true; /* loosing data is not considered an error, it is just a missing feature
+					either in this code or in the cml schema */
+}
+
+void CDXMLLoader::AddIntProperty (xmlNodePtr node, char const *id, int value)
+{
+	char *buf = g_strdup_printf("%d", value);
+	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar const *> (buf));
+	g_free (buf);
+}
+
+void CDXMLLoader::AddStringProperty (xmlNodePtr node, char const *id, string &value)
+{
+	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar const *> (value.c_str ()));
+}
+
+bool CDXMLLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io, G_GNUC_UNUSED ContentType type)
 {
 	map<string, CDXMLFont> fonts;
+	Document *doc = dynamic_cast <Document *> (obj);
+	xmlNodePtr colors, fonttable, page;
+	if (!doc || !out)
+		return false;
 
-	if (NULL != out) {
-		GsfXMLOut *xml = gsf_xml_out_new (out);
-		gsf_xml_out_set_doc_type (xml, "<!DOCTYPE CDXML SYSTEM \"http://www.cambridgesoft.com/xml/cdxml.dtd\">");
-		gsf_xml_out_start_element (xml, "CDXML");
-		gsf_xml_out_end_element (xml);
-		g_object_unref (xml);
-		return true;
+	m_MaxId = m_Z = 1;
+
+	// Init default colors
+	m_Colors[2] = GO_COLOR_WHITE;
+	m_Colors[3] = GO_COLOR_BLACK;
+	m_Colors[4] = GO_COLOR_RED;
+	m_Colors[5] = GO_COLOR_YELLOW;
+	m_Colors[6] = GO_COLOR_GREEN;
+	m_Colors[7] = GO_COLOR_CYAN;
+	m_Colors[8] = GO_COLOR_BLUE;
+	m_Colors[9] = GO_COLOR_VIOLET;
+
+	// Init fonts, we always use Unknown as the charset, hoping it is not an issue
+	m_Fonts[3] = (CDXMLFont) {3, string ("Unknown"), string ("Arial")};
+	m_Fonts[4] = (CDXMLFont) {4, string ("Unknown"), string ("Times New Roman")};
+
+	/* we can't use sax, because we need colors and fonts */
+	xmlDocPtr xml = xmlNewDoc (reinterpret_cast <xmlChar const *> ("1.0"));
+	xmlDocSetRootElement (xml,  xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("CDXML"), NULL));
+	std::string app = doc->GetApp ()->GetName () + " "VERSION;
+	xmlNewProp (xml->children, reinterpret_cast <xmlChar const *> ("CreationProgram"),
+	            reinterpret_cast <xmlChar const *> (app.c_str ()));
+	// determine the bond length and scale the document appropriately
+	string prop = doc->GetProperty (GCU_PROP_THEME_BOND_LENGTH);
+	double scale = strtod (prop.c_str (), NULL);
+	doc->SetScale (scale / 30.);
+	xmlNewProp (xml->children, reinterpret_cast <xmlChar const *> ("BondLength"),
+	            reinterpret_cast <xmlChar const *> ("30"));
+	// add color table
+	colors = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("colortable"), NULL);
+	xmlAddChild (xml->children, colors);
+	// add font table
+	fonttable = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("fonttable"), NULL);
+	xmlAddChild (xml->children, fonttable);
+	// start page
+	page = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("page"), NULL);
+	xmlAddChild (xml->children, page);
+	// build tree from children
+	std::map <std::string, Object *>::iterator i;
+	Object *child = doc->GetFirstChild (i);
+	while (child) {
+		if (!WriteObject (xml, page, child, io)) {
+			xmlFreeDoc (xml);
+			m_Colors.clear ();
+			m_Fonts.clear ();
+			m_SavedIds.clear ();
+			return false;
+		}
+		child = doc->GetNextChild (i);
 	}
-	return false;
+	// add colors to color table
+	map <unsigned, GOColor>::iterator color, end_color = m_Colors.end ();
+	for (color = m_Colors.begin (); color != end_color; color++) {
+		xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("color"), NULL);
+		xmlAddChild (colors, node);
+		char *buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_R ((*color).second));
+		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("r"), reinterpret_cast <xmlChar const *> (buf));
+		g_free (buf);
+		buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_G ((*color).second));
+		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("g"), reinterpret_cast <xmlChar const *> (buf));
+		g_free (buf);
+		buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_B ((*color).second));
+		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("b"), reinterpret_cast <xmlChar const *> (buf));
+		g_free (buf);
+	}
+	// write fonts
+	map <unsigned, CDXMLFont>::iterator font, end_font = m_Fonts.end ();
+	for (font = m_Fonts.begin (); font != end_font; font++) {
+		xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
+		xmlAddChild (fonttable, node);
+		AddIntProperty (node, "id", (*font).second.index);
+		AddStringProperty (node, "charset", (*font).second.encoding);
+		AddStringProperty (node, "name", (*font).second.name);
+	}
+	xmlIndentTreeOutput = true;
+	xmlKeepBlanksDefault (0);
+	xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
+	buf->context = out;
+	buf->closecallback = NULL;
+	buf->writecallback = (xmlOutputWriteCallback) cb_xml_to_vfs;
+	start = true;
+	xmlSaveFormatFileTo (buf, xml, NULL, true);
+	xmlFreeDoc (xml);
+	m_Colors.clear ();
+	m_Fonts.clear ();
+	m_SavedIds.clear ();
+	return true;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -790,14 +1015,14 @@ extern GOPluginModuleHeader const go_plugin_header =
 	{ GOFFICE_MODULE_PLUGIN_MAGIC_NUMBER, G_N_ELEMENTS (go_plugin_depends) };
 
 G_MODULE_EXPORT void
-go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
+go_plugin_init (G_GNUC_UNUSED GOPlugin *plugin, G_GNUC_UNUSED GOCmdContext *cc)
 {
 	bindtextdomain (GETTEXT_PACKAGE, DATADIR"/locale");
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 }
 
 G_MODULE_EXPORT void
-go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
+go_plugin_shutdown (G_GNUC_UNUSED GOPlugin *plugin, G_GNUC_UNUSED GOCmdContext *cc)
 {
 }
 
