@@ -26,12 +26,17 @@
 #define GCHEMPAINT_CYCLE_TOOL_H
 
 #include <gcp/tool.h>
+#include <gccv/structs.h>
 
 namespace gcu {
 	class Atom;
 	class Chain;
 }
 
+namespace gcp {
+	class Atom;
+}
+
 class gcpCycleTool: public gcp::Tool
 {
 public:
@@ -51,10 +56,12 @@ protected:
 	void Init ();
 	bool CheckIfAllowed ();
 
+private:
+	void Draw ();
+
 protected:
-	double *m_xn;
 	unsigned char m_size;
-	GnomeCanvasPoints *points;
+	gccv::Point *m_Points;
 	GtkSpinButton *m_LengthBtn;
 	GtkToggleButton *m_MergeBtn;
 
