@@ -53,6 +53,7 @@ class GChemCalc: public Application, public Printable
 {
 public:
 	GChemCalc ();
+	~GChemCalc ();
 	Formula formula;
 	GtkLabel *markup, *raw, *weight, *mono, *monomass;
 	GtkWidget *graph_widget;
@@ -125,6 +126,11 @@ GChemCalc::GChemCalc ():
 	g_free (name);
 }
 
+GChemCalc::~GChemCalc ()
+{
+	g_object_unref (m_UIManager);
+}
+
 void GChemCalc::ParseNodes (xmlNodePtr node)
 {
 	Residue* r;
@@ -300,14 +306,14 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	const gchar * translator_credits = _("translator_credits");
 
 	gtk_show_about_dialog (NULL,
-	                       "name", "GChemCalc",
+	                       "program-name", "GChemCalc",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
