@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -28,6 +28,8 @@
 #include "application.h"
 #include <glib/gi18n.h>
 
+using namespace std;
+
 enum
 {
 	COLUMN_X1,
@@ -45,17 +47,17 @@ struct LineStruct {
 	bool duplicated;
 };
 
-static void on_add (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_add (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineAdd ();
 }
 
-static void on_delete (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_delete (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineDelete ();
 }
 
-static void on_delete_all (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_delete_all (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineDeleteAll ();
 }
@@ -75,38 +77,33 @@ static void on_toggled (GtkCellRendererToggle *cell, const gchar *path_string, g
 	pBox->OnToggled (cell, path_string);
 }
 
-static void on_edges_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_edges_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial(edges);
 }
 
-static void on_diags_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_diags_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial (diagonals);
 }
 
-static void on_medians_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_medians_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial (medians);
 }
 
-gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLADEDIR"/lines.glade", "lines", pDoc)
+gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, UIDIR"/lines.ui", "lines", GETTEXT_PACKAGE, pDoc)
 {
-	if (!xml) {
-		m_Lines = NULL;
-		delete this;
-		return;
-	}
 	m_pDoc = pDoc;
-	GtkWidget* button = glade_xml_get_widget (xml, "add");
-	g_signal_connect (G_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (on_add), this);
-	DeleteBtn = glade_xml_get_widget (xml, "delete");
+	GtkWidget* button = GetWidget ("add");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_add), this);
+	DeleteBtn = GetWidget ("delete");
 	gtk_widget_set_sensitive (DeleteBtn,0);
 	g_signal_connect (G_OBJECT (DeleteBtn), "clicked", G_CALLBACK (on_delete), this);
-	DeleteAllBtn = glade_xml_get_widget (xml, "delete_all");
-	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", GTK_SIGNAL_FUNC (on_delete_all), this);
+	DeleteAllBtn = GetWidget ("delete_all");
+	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", G_CALLBACK (on_delete_all), this);
 	LineList = gtk_list_store_new (7, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_BOOLEAN);
-	GtkTreeView* tree = (GtkTreeView *) glade_xml_get_widget (xml, "lineslist");
+	GtkTreeView* tree = GTK_TREE_VIEW (GetWidget ("lineslist"));
 	Selection = gtk_tree_view_get_selection (tree);
 	gtk_tree_view_set_model (tree, GTK_TREE_MODEL (LineList));
 	GtkCellRenderer *renderer;
@@ -116,7 +113,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set (G_OBJECT (renderer), "editable", true, NULL);
 	g_object_set_data (G_OBJECT (renderer), "column", (gint *) COLUMN_X1);
-	column = gtk_tree_view_column_new_with_attributes ("x1", renderer, "text", COLUMN_X1, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("x1"), renderer, "text", COLUMN_X1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -126,7 +123,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set (G_OBJECT (renderer), "editable", true, NULL);
 	g_object_set_data (G_OBJECT (renderer), "column", (gint *) COLUMN_Y1);
-	column = gtk_tree_view_column_new_with_attributes ("y1", renderer, "text", COLUMN_Y1, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("y1"), renderer, "text", COLUMN_Y1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -136,7 +133,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set (G_OBJECT (renderer), "editable", true, NULL);
 	g_object_set_data (G_OBJECT (renderer), "column", (gint *) COLUMN_Z1);
-	column = gtk_tree_view_column_new_with_attributes ("z1", renderer, "text", COLUMN_Z1, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("z1"), renderer, "text", COLUMN_Z1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -146,7 +143,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_X2);
-	column = gtk_tree_view_column_new_with_attributes ("x2", renderer, "text", COLUMN_X2, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("x2"), renderer, "text", COLUMN_X2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -156,7 +153,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set (G_OBJECT (renderer), "editable", true, NULL);
 	g_object_set_data (G_OBJECT (renderer), "column", (gint *) COLUMN_Y2);
-	column = gtk_tree_view_column_new_with_attributes ("y2", renderer, "text", COLUMN_Y2, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("y2"), renderer, "text", COLUMN_Y2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -166,7 +163,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set (G_OBJECT (renderer), "editable", true, NULL);
 	g_object_set_data (G_OBJECT (renderer), "column", (gint *) COLUMN_Z2);
-	column = gtk_tree_view_column_new_with_attributes ("z2", renderer, "text", COLUMN_Z2, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("z2"), renderer, "text", COLUMN_Z2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
@@ -181,25 +178,25 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), 50);
 	gtk_tree_view_append_column (tree, column);
 	m_Lines = g_array_sized_new (FALSE, FALSE, sizeof (struct LineStruct), 1);
-	LineColor = (GtkColorButton *) glade_xml_get_widget (xml, "color");
-	LineR = (GtkEntry *) glade_xml_get_widget (xml, "radius");
-	Edges = (GtkCheckButton *) glade_xml_get_widget (xml, "edges");
+	LineColor = GTK_COLOR_BUTTON (GetWidget ("color"));
+	LineR = GTK_ENTRY (GetWidget ("radius"));
+	Edges = GTK_CHECK_BUTTON (GetWidget ("edges"));
 	g_signal_connect (G_OBJECT (Edges), "toggled", G_CALLBACK (on_edges_toggled), this);
-	EdgesColor = (GtkColorButton *) glade_xml_get_widget (xml, "edges-color");
+	EdgesColor = GTK_COLOR_BUTTON (GetWidget ("edges-color"));
 	gtk_widget_set_sensitive (GTK_WIDGET (EdgesColor), false);
-	EdgesR = (GtkEntry *) glade_xml_get_widget (xml, "edges_radius");
+	EdgesR = GTK_ENTRY (GetWidget ("edges_radius"));
 	gtk_widget_set_sensitive (GTK_WIDGET (EdgesR), false);
-	Medians = (GtkCheckButton *) glade_xml_get_widget (xml, "medians");
+	Medians = GTK_CHECK_BUTTON (GetWidget ("medians"));
 	g_signal_connect (G_OBJECT (Medians), "toggled", G_CALLBACK (on_medians_toggled), this);
-	MediansColor = (GtkColorButton *) glade_xml_get_widget (xml, "med-color");
+	MediansColor = GTK_COLOR_BUTTON (GetWidget ("med-color"));
 	gtk_widget_set_sensitive (GTK_WIDGET (MediansColor), false);
-	MediansR = (GtkEntry *) glade_xml_get_widget (xml, "med_radius");
+	MediansR = GTK_ENTRY (GetWidget ("med_radius"));
 	gtk_widget_set_sensitive (GTK_WIDGET (MediansR), false);
-	Diags = (GtkCheckButton *) glade_xml_get_widget (xml, "diagonals");
+	Diags = GTK_CHECK_BUTTON (GetWidget ("diagonals"));
 	g_signal_connect (G_OBJECT (Diags), "toggled", G_CALLBACK (on_diags_toggled), this);
-	DiagsColor = (GtkColorButton *) glade_xml_get_widget (xml, "diag-color");
+	DiagsColor = GTK_COLOR_BUTTON (GetWidget ("diag-color"));
 	gtk_widget_set_sensitive (GTK_WIDGET (DiagsColor), false);
-	DiagsR = (GtkEntry *) glade_xml_get_widget (xml, "diag_radius");
+	DiagsR = GTK_ENTRY (GetWidget ("diag_radius"));
 	gtk_widget_set_sensitive (GTK_WIDGET (DiagsR), false);
 	m_LineSelected = -1;
 	CrystalLineList* Lines = m_pDoc->GetLineList ();
@@ -270,7 +267,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 			break;
 		}
 	}
-	g_signal_connect (G_OBJECT (Selection), "changed", GTK_SIGNAL_FUNC (on_select), this);
+	g_signal_connect (G_OBJECT (Selection), "changed", G_CALLBACK (on_select), this);
 	if (!m_Lines->len)
 		gtk_widget_set_sensitive (DeleteAllBtn, false);
 }
@@ -303,7 +300,7 @@ bool gcLinesDlg::Apply ()
 	//Add edged, diagonals and medians
 	CrystalLine* pLine;
 	double r, Red, Green, Blue, Alpha;
-	if (GTK_TOGGLE_BUTTON (Edges)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Edges))) {
 		GetNumber (EdgesR, &r, Min, 0);
 		if (r > 0.0) {
 			gtk_color_button_get_color (EdgesColor, &color);
@@ -315,7 +312,7 @@ bool gcLinesDlg::Apply ()
 			Lines->push_back (pLine);
 		}
 	}
-	if (GTK_TOGGLE_BUTTON (Diags)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Diags))) {
 		GetNumber (DiagsR, &r, Min, 0);
 		if (r > 0.0) {
 			gtk_color_button_get_color (DiagsColor, &color);
@@ -327,7 +324,7 @@ bool gcLinesDlg::Apply ()
 			Lines->push_back (pLine);
 		}
 	}
-	if (GTK_TOGGLE_BUTTON (Medians)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Medians))) {
 		GetNumber (MediansR, &r, Min, 0);
 		if (r > 0.0) {
 			gtk_color_button_get_color (MediansColor, &color);
@@ -475,7 +472,7 @@ void gcLinesDlg::OnEdited (GtkCellRendererText *cell, const gchar *path_string,
 	gtk_tree_path_free (path);
 }
 
-void gcLinesDlg::OnToggled (GtkCellRendererToggle *cell, const gchar *path_string)
+void gcLinesDlg::OnToggled (G_GNUC_UNUSED GtkCellRendererToggle *cell, const gchar *path_string)
 {
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
@@ -493,16 +490,16 @@ void gcLinesDlg::OnToggledSpecial (int Type)
 {
 	switch (Type) {
 	case edges:
-		gtk_widget_set_sensitive (GTK_WIDGET (EdgesColor), GTK_TOGGLE_BUTTON (Edges)->active);
-		gtk_widget_set_sensitive (GTK_WIDGET (EdgesR), GTK_TOGGLE_BUTTON (Edges)->active);
+		gtk_widget_set_sensitive (GTK_WIDGET (EdgesColor), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Edges)));
+		gtk_widget_set_sensitive (GTK_WIDGET (EdgesR), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Edges)));
 		break;
 	case diagonals:
-		gtk_widget_set_sensitive (GTK_WIDGET (DiagsColor), GTK_TOGGLE_BUTTON (Diags)->active);
-		gtk_widget_set_sensitive (GTK_WIDGET (DiagsR), GTK_TOGGLE_BUTTON (Diags)->active);
+		gtk_widget_set_sensitive (GTK_WIDGET (DiagsColor), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Diags)));
+		gtk_widget_set_sensitive (GTK_WIDGET (DiagsR), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Diags)));
 		break;
 	case medians:
-		gtk_widget_set_sensitive (GTK_WIDGET (MediansColor), GTK_TOGGLE_BUTTON (Medians)->active);
-		gtk_widget_set_sensitive (GTK_WIDGET (MediansR), GTK_TOGGLE_BUTTON (Medians)->active);
+		gtk_widget_set_sensitive (GTK_WIDGET (MediansColor), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Medians)));
+		gtk_widget_set_sensitive (GTK_WIDGET (MediansR), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (Medians)));
 		break;
 	}
 }
