@@ -4,7 +4,7 @@
  * Gnome Crystal
  * window.cc 
  *
- * Copyright (C) 2006-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -146,17 +146,17 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
 	char const *translator_credits = _("translator_credits");
 	GdkPixbuf *logo = gdk_pixbuf_new_from_file (PIXMAPSDIR"/gcrystal_logo.png", NULL);
 	gtk_show_about_dialog (NULL,
-					"name", _("Gnome Crystal"),
+					"program-name", _("Gnome Crystal"),
 					"authors", authors,
 					"artists", artists,
 					"comments", _("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
-					"copyright", _("Copyright © 1999-2008 by Jean Bréfort"),
+					"copyright", _("Copyright © 1999-2010 by Jean Bréfort"),
 					"license", license,
 					"logo", logo,
 					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? 
 											translator_credits : NULL,
 					"version", VERSION,
-					"website", "http://www.nongnu.org/gchemutils",
+					"website", "http://gchemutils.nongnu.org",
 					NULL);
 	g_object_unref (logo);
 }
@@ -434,7 +434,12 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
-	gtk_recent_filter_add_mime_type (filter, "application/x-gcrystal");
+	std::list<std::string>::iterator it;
+	char const * mime = App->GetFirstSupportedMimeType (it);
+	while (mime) {
+		gtk_recent_filter_add_mime_type (filter, mime);
+		mime = App->GetNextSupportedMimeType (it);
+	}
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
 	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
 	GtkWidget *item = gtk_menu_item_new_with_label (_("Open recent"));
@@ -466,6 +471,7 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 
 gcWindow::~gcWindow ()
 {
+	g_object_unref (m_UIManager);
 }
 
 void gcWindow::ClearStatus()
