@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/window.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,14 +28,7 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/print-setup-dlg.h>
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/graph/gog-object-xml.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-image.h>
 #include <gsf/gsf-output-memory.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtkwindow.h>
 #include <glib/gi18n.h>
 
 using namespace std;
@@ -123,7 +116,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GSpectrum is a spectrum viewer for Gnome");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2007-2008 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2007-2010 Jean Bréfort\n");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -143,14 +136,14 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (NULL,
-	                       "name", "GSpectrum",
+	                       "program-name", "GSpectrum",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
@@ -162,6 +155,43 @@ static void on_recent (GtkRecentChooser *widget, gsvWindow *Win)
 	gtk_recent_info_unref(info);
 }
 
+
+static bool on_motion (GOGraphWidget *widget, GdkEventMotion *event, G_GNUC_UNUSED gpointer data)
+{
+	GogChart *chart = go_graph_widget_get_chart (widget);
+	GogRenderer *rend = go_graph_widget_get_renderer (widget);
+	GogView *graph_view;
+	GogAxis *x_axis, *y_axis;
+	g_object_get (G_OBJECT (rend), "view", &graph_view, NULL);
+	GSList *l = gog_object_get_children (GOG_OBJECT (chart), gog_object_find_role_by_name (GOG_OBJECT (chart), "Plot"));
+	GogPlot *plot = reinterpret_cast <GogPlot *> (l->data);
+	g_slist_free (l);
+	GogView *view = gog_view_find_child_view (graph_view, GOG_OBJECT (plot));
+	l = gog_chart_get_axes (chart, GOG_AXIS_X);
+	x_axis = GOG_AXIS (l->data);
+	g_slist_free (l);
+	l = gog_chart_get_axes (chart, GOG_AXIS_Y);
+	y_axis = GOG_AXIS (l->data);
+	g_slist_free (l);
+    GogChartMap *map = gog_chart_map_new (chart,
+            &(view->allocation), x_axis, y_axis, NULL, FALSE);
+	if (gog_chart_map_is_valid (map) &&
+			event->x >= view->allocation.x && event->x < view->allocation.x + view->allocation.w &&
+			event->y >= view->allocation.y && event->y < view->allocation.y + view->allocation.h) {
+		GogAxisMap *x_map = gog_chart_map_get_axis_map (map, 0);
+		GogAxisMap *y_map = gog_chart_map_get_axis_map (map, 1);
+		double x = gog_axis_map_from_view (x_map, event->x);
+		double y = gog_axis_map_from_view (y_map, event->y);
+		char *buf = g_strdup_printf ("x=%g y=%g", x, y);
+		gtk_widget_set_tooltip_text (GTK_WIDGET (widget), buf);
+		g_free (buf);
+	} else
+		gtk_widget_set_tooltip_text (GTK_WIDGET (widget), "");
+	gog_chart_map_free (map);
+	g_object_unref (G_OBJECT (graph_view));
+	return true;
+}
+
 static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File"), NULL, NULL, NULL },
 	  { "Open", GTK_STOCK_OPEN, N_("_Open..."), "<control>O",
@@ -230,6 +260,7 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	m_Doc = Doc;
 	m_Window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 	gtk_window_set_default_size (m_Window, 600, 400);
+	gtk_window_set_icon_name (m_Window, App->GetIconName ().c_str ());
 	g_signal_connect (G_OBJECT (m_Window), "delete-event", G_CALLBACK (on_delete_event), this);
 
 	GtkWidget *vbox = gtk_vbox_new (FALSE, 0);
@@ -263,8 +294,11 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	m_View = dynamic_cast<gsvView *> (m_Doc->GetView ());
 	m_View->SetWindow (this);
 	gtk_box_pack_start (GTK_BOX (vbox), m_View->GetOptionBox (), FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (vbox), m_View->GetWidget ());
+	w = m_View->GetWidget ();
+	g_signal_connect (G_OBJECT (w), "motion-notify-event", G_CALLBACK (on_motion), NULL);
+	gtk_container_add (GTK_CONTAINER (vbox), w);
 	gtk_widget_show_all (GTK_WIDGET (m_Window));
+	g_object_unref (ui_manager);
 	// Initialize print settings
 }
 
@@ -320,7 +354,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -351,7 +385,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		g_object_unref (output);
 		g_free (format);
 		gtk_selection_data_set (selection_data,
-					selection_data->target, 8,
+					gtk_selection_data_get_target (selection_data), 8,
 					(guchar *) buffer, osize);
 		g_free (buffer);
 	}
